@@ -1,5 +1,5 @@
 from abc import ABC
-from GhostScan.CalibrationSessions import CalibrationSession
+from GhostScan.CalibrationSession import CalibrationSession
 
 
 class GeometricCalibSession(CalibrationSession, ABC):
