@@ -1,5 +1,5 @@
 from abc import ABC
-from CalibrationSession import CalibrationSession
+from GhostScan.CalibrationSession import CalibrationSession
 
 
 class IntrinsicCalibSession(CalibrationSession, ABC):
